MirrarSDK class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertImageUpload(
File imageFile) → Future< bool> -
fetchHairStyle(
[String brandID = 'ec3e6733-cdd4-474f-b01d-c073655fa105', String subBrandID = 'a9562e09-7a61-472f-a1f7-e719c897e97c']) → Future< String> -
getImageFilter(
String imagePath, String imageId) → Future< String> -
getSubBrandId(
String brandId) → Future< String> -
myApiFunction(
String _base64String) → Future< String>